
# Type: in cell population with


holds between two genes or gene products that are expressed in the same cell type or population

URI: [biolink:in_cell_population_with](https://w3id.org/biolink/vocab/in_cell_population_with)


## Domain and Range

[GeneOrGeneProduct](GeneOrGeneProduct.md) ->  <sub>0..*</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [coexists with](coexists_with.md)

## Children


## Used by

 * [RNAProduct](RNAProduct.md)
 * [RNAProductIsoform](RNAProductIsoform.md)
 * [Gene](Gene.md)
 * [GeneOrGeneProduct](GeneOrGeneProduct.md)
 * [GeneProduct](GeneProduct.md)
 * [GeneProductIsoform](GeneProductIsoform.md)
 * [MicroRNA](MicroRNA.md)
 * [NoncodingRNAProduct](NoncodingRNAProduct.md)
 * [Protein](Protein.md)
 * [ProteinIsoform](ProteinIsoform.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |

